@@ -22,8 +22,10 @@ def get_version():
     """returns version of the askbot app
     this version is meaningful for pypi only
     """
-    return '0.6.11'
+    return '0.6.12'
 
+#todo: maybe send_mail functions belong to models
+#or the future API
 def send_mail(
             subject_line = None,
             body_text = None,
@@ -44,9 +46,11 @@ def send_mail(
 
     if raise_on_failure is True, exceptions.EmailNotSent is raised
     """
-    #print subject_line
-    #print body_text
+    from askbot.conf import settings as askbot_settings
+    prefix = askbot_settings.EMAIL_SUBJECT_PREFIX.strip() + ' '
     try:
+        assert(subject_line is not None)
+        subject_line = prefix + subject_line
         msg = mail.EmailMessage(
                         subject_line, 
                         body_text, 
@@ -62,3 +66,24 @@ def send_mail(
         logging.critical(unicode(e))
         if raise_on_failure == True:
             raise exceptions.EmailNotSent(unicode(e))
+
+def mail_moderators(subject_line, body_text):
+    """sends email to forum moderators and admins
+    """
+    from django.db.models import Q
+    from askbot.models import User
+    recipient_list = User.objects.filter(
+                    Q(status='m') | Q(is_superuser=True)
+                ).values_list('email', flat=True)
+    recipient_list = set(recipient_list)
+
+    from_email = ''
+    if hasattr(django_settings, 'DEFAULT_FROM_EMAIL'):
+        from_email = django_settings.DEFAULT_FROM_EMAIL
+
+    try:
+        mail.send_mail(subject_line, body_text, from_email, recipient_list)
+    except smtplib.SMPTException, e:
+        logging.critical(unicode(e))
+        if raise_on_failure == True:
+            raise exceptions.EmailNotSent(unicode(e))
