@@ -52,6 +52,60 @@ var i18nZh = {
     'upload image':'或者上传本地图片：'
 };
 
+var i18nZhtw = {
+    'insufficient privilege':'權限不足',
+    'cannot pick own answer as best':'不能蔽掃自珍',
+    'anonymous users cannot select favorite questions':'匿名用戶不能收藏問題',
+    'please login':'請先登錄',
+    'please see': '查看',
+    'daily vote cap exhausted':'對不起，您已用完今日所有的投票。',
+    'please confirm offensive':"確定要歸類該帖為廣告、人身攻擊、惡意言論嗎？",
+    'anonymous users cannot flag offensive posts':'匿名用戶不能操作',
+    'cannot flag message as offensive twice':'不能重複操作。',
+    'flag offensive cap exhausted':'對不起，您已用完今日所有的5次『水帖』操作。',
+    'need >15 points to report spam':"需要 >15 積分才能歸類『垃圾帖』。",
+    'confirm delete':"確定刪除",
+    'anonymous users cannot delete/undelete':"匿名用戶不能刪除或恢復帖子",
+    'post recovered':"操作成功！該帖子已被恢複。",
+    'post deleted':"操作成功！該帖子已刪除。",
+    'add comment':'添加評論',
+    'community karma points':'社區積分',
+    'to comment, need':'評論需要',
+    'delete this comment':'刪除此評論',
+    'hide comments':"隱藏評論",
+    'add a comment':"添加評論",
+    'comments':"評論",
+    'confirm delete comment':"刪除評論確認",
+    'characters':'字',
+    'can write':'還可寫',
+    'click to close':'點擊消息框關閉',
+    'loading...':'讀取中...',
+    'tags cannot be empty':'標籤不能為空白',
+    'tablimits info':"最多5個標籤，每個標籤長度小於20個字符。",
+    'content cannot be empty':'內容不能為空白',
+    'content minchars': '請輸入至少 {0} 字符。',
+    'please enter title':'請輸入標題。',
+    'title minchars':"請輸入至少 {0} 字符。",
+    'delete':'刪除',
+    'undelete':	'取消',
+    'bold':'粗體',
+    'italic':'斜體',
+    'link':'超連接',
+    'quote':'引用',
+    'preformatted text':'代碼',
+    'image':'圖片',
+    'numbered list':'數字編號列表',
+    'bulleted list':'項目符號列表',
+    'heading':'標題',
+    'horizontal bar':'水平線',
+    'undo':'撤銷',
+    'redo':'重做',
+    'enter image url':'<b>輸入圖片地址</b></p><p>示例：<br />http://www.example.com/image.jpg   \"我的截圖\"',
+    'enter url':'<b>輸入Web地址</b></p><p>示例：<br />http://www.cnprog.com/   \"我的網站\"</p>"',
+    'upload image':'或者上傳本地圖片：'
+};
+
+
 var i18nEn = {
     "anonymous users cannot vote": "sorry, anonymous users cannot vote ",
     'need >15 points to report spam':'need >15 points to report spam ',
@@ -315,7 +369,7 @@ var i18nDe = {
     'moderate-user/': 'benutzer-moderieren/',
     'account/': 'zugang/',
     'signin/': 'einloggen/'
-}
+};
 
 
 var i18nRu = {
@@ -381,7 +435,75 @@ var i18nRu = {
     'interesting/':'интересная/',
     'command/':'комманда/',
     'moderate-user/': 'модерировать-пользователя/'
-}
+};
+
+var i18nFr = {
+    "anonymous users cannot vote":"les utilisateurs anonyment ne peuvent pas voter ",
+    'add a comment': 'Ajouter un commentaire', 
+    'add comment': 'OK', 
+    'anonymous users cannot delete/undelete': 'Les utilisateurs anonymes ne peuvent pas supprimer/restaurer', 
+    'anonymous users cannot flag offensive posts': 'Les utilisateurs anonymes ne peuvent pas signaler les messages à contenu abusif', 
+    'anonymous users cannot select favorite questions': 'Les utilisateurs anonymes ne peuvent pas sélectionner leurs questions favorites', 
+    'bold': 'gras', 
+    'bulleted list': 'liste', 
+    'can write': 'peut écrire ', 
+    'cannot flag message as offensive twice': 'Vous ne pouvez pas signaler deux fois un message à contenu abusif', 
+    'cannot pick own answer as best': 'Vous ne pouvez pas désigner une de vos propres réponses comme étant la meilleure réponse', 
+    'characters': 'caractères', 
+    'click to close': 'cliquez pour fermer', 
+    'comments': 'commentaires', 
+    'community karma points': ' Points de karma - ', 
+    'confirm delete': 'Confirmer la suppression', 
+    'confirm delete comment': 'Confirmer la suppression du commentaire', 
+    'content cannot be empty': 'Le contenu ne doit pas être vide', 
+    'content minchars': 'Veuillez saisir au moins {0} caractères', 
+    'daily vote cap exhausted': 'Votre quota journalier de votes est atteint', 
+    'delete': 'supprimer', 
+    'delete this comment': 'supprimer ce commentaire', 
+    'enter image url': 'Veuillez saisir une URL menant à une image, par exemple <br />http://www.votre-domaine.com/nom-image.jpg', 
+    'enter url': 'Entrez une URL, par exemple <br />http://www.askbot.org/ </p>', 
+    'flag offensive cap exhausted': 'Votre quota journalier de signalements de contenus abusifs a été atteint', 
+    'heading': 'Titre', 
+    'hide comments': 'Masquer les commentaires', 
+    'horizontal bar': 'Barre horizontale', 
+    'image': 'Image', 
+    'insufficient privilege': 'Privilèges insuffisants', 
+    'italic': 'italique', 
+    'link': 'lien', 
+    'loading...': 'Chargement en cours...', 
+    'need >15 points to report spam': 'Vous devez avoir au moins 15 points de réputation pour signaler du spam', 
+    'numbered list': 'liste numérotée', 
+    'please confirm offensive': 'Veuillez confirmer que le contenu est abusif', 
+    'please enter title': 'Veuillez saisir un titre', 
+    'please login': 'Veuillez vous authentifier', 
+    'please see': 'Pour en savoir plus', 
+    'post deleted': 'Message supprimé', 
+    'post recovered': 'Message restauré', 
+    'preformatted text': 'Texte préformaté', 
+    'quote': 'Citer', 
+    'redo': 'Rétablir', 
+    "tablimits info": "Jusqu'à cinq mots-clés (tags), chacun comportant jusqu'à 20 caractères", 
+    'tags cannot be empty': 'Les mots-clés ne doivent pas être vides', 
+    'title minchars': 'Veuillez saisir au moins {0} caractères', 
+    "to comment, need": "Pour faire des commentaires sur les commentaires d'autres utilisateurs, vous devez avoir au moins ", 
+    'undelete': 'Restaurer', 
+    'undo': 'Annuler', 
+    'upload image': 'Charger une image', 
+    'questions/': 'questions/', 
+    'question/': 'question/',
+    'delete/': 'supprimer/', 
+    'comments/': 'commentaires/', 
+    'answers/': 'reponses/', 
+    'vote/': 'voter/',
+    'unmark-tag/':'retirer-un-tag/',
+    'ignored/':'ignoree/',
+    'mark-tag/':'marquer-avec-un-tag/',
+    'interesting/':'interessant/',
+    'command/':'commande/',
+    'moderate-user/': 'moderer-utilisateur/',
+    'account/': 'compte/',
+    'signin/': 'connexion/'
+};
 
 var i18n = {
     'en':i18nEn,
@@ -389,7 +511,10 @@ var i18n = {
     'es':i18nEs,
     'tr':i18nTr,
     'de':i18nDe,
-    'ru':i18nRu
+    'ru':i18nRu,
+    'fr':i18nFr,
+    'zh-tw':i18nZhtw
 };
 
 var i18n_dict = i18n[i18nLang];
+
