@@ -2,6 +2,7 @@ from django.test import TestCase
 from django.template import defaultfilters
 from django.core.urlresolvers import reverse
 from askbot import models
+from askbot.utils.slug import slugify
 
 class PageLoadTestCase(TestCase):
     def try_url(
@@ -129,14 +130,20 @@ class PageLoadTests(PageLoadTestCase):
         self.try_url(
                 'question',
                 kwargs={'id':1},
+                follow=True,
+                template='question.html'
             )
         self.try_url(
                 'question',
                 kwargs={'id':2},
+                follow=True,
+                template='question.html'
             )
         self.try_url(
                 'question',
                 kwargs={'id':3},
+                follow=True,
+                template='question.html'
             )
         self.try_url(
                 'question_revisions',
@@ -223,7 +230,7 @@ class PageLoadTests(PageLoadTestCase):
 
     def test_user_urls(self):
         user = models.User.objects.get(id=2)
-        name_slug = defaultfilters.slugify(user.username)
+        name_slug = slugify(user.username)
         self.try_url(
             'user_profile', 
             kwargs={'id': 2, 'slug': name_slug},
